# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations


class Migration(migrations.Migration):

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Bookmark',
            fields=[
                ('id', models.AutoField(verbose_name='ID', auto_created=True, primary_key=True, serialize=False)),
                ('name', models.CharField(max_length=255)),
                ('uri', models.CharField(max_length=4096)),
            ],
            options={
                'ordering': ('name',),
            },
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name='Notice',
            fields=[
                ('id', models.AutoField(verbose_name='ID', auto_created=True, primary_key=True, serialize=False)),
                ('slug', models.CharField(max_length=255)),
                ('date', models.DateField(auto_now_add=True)),
                ('creation_date', models.DateTimeField(auto_now_add=True)),
                ('group_name', models.CharField(max_length=255)),
                ('group_val', models.IntegerField(default=0)),
                ('low_limit', models.IntegerField(default=0)),
                ('high_limit', models.IntegerField(default=0)),
                ('prev_val', models.IntegerField(default=0)),
            ],
            options={
            },
            bases=(models.Model,),
        ),
    ]



import datetime

from django import template
from django_spreadsheet_reports.models import Notice


register = template.Library()


def easy_tag(func):
    """
    Decorator to facilitate template tag creation

    deal with the repetitive parts of parsing template tags
    """

    def inner(parser, token):
        # print token
        try:
            return func(*token.split_contents())
        except TypeError:
            raise template.TemplateSyntaxError(
                'Bad arguments for tag "%s"' % token.split_contents()[0])

    inner.__name__ = func.__name__
    inner.__doc__ = inner.__doc__
    return inner


class AppendGetNode(template.Node):
    def __init__(self, d):
        self.dict_pairs = []
        for pair in d.split(','):
            pair = pair.split('=')
            row = (pair[0], template.Variable(pair[1]))
            self.dict_pairs.append(row)

    def render(self, context):
        get = context['request'].GET.copy()
        for key, value in self.dict_pairs:
            get[key] = value.resolve(context)
        path = context['request'].META['PATH_INFO']
        if len(get):
            path += "?%s" % get.urlencode()
        return path


@register.tag()
@easy_tag
def append_to_get(_tag_name, d):
    return AppendGetNode(d)


@register.simple_tag
def display_column(table, value, counter):
    key = table.columns[counter].accessor
    if hasattr(table.columns[key].column, 'choices'):
        d = dict(table.columns[key].column.choices)
        if value is None:
            return 'None'
        return d[value]
    return value


@register.inclusion_tag('django_spreadsheet_reports/notice_list.html')
def show_notice_list(hours_ago=72):
    cutoff = datetime.datetime.now() - datetime.timedelta(hours=hours_ago)
    notices = Notice.objects.filter(
        creation_date__gte=cutoff).order_by('-id')
    return {'notices': notices}



import logging
from optparse import make_option

import lockfile
from django.core.management import base
from django.db import transaction

from django_spreadsheet_reports.utils import save_reports, load_from_urls


logger = logging.getLogger(__name__)


class Command(base.NoArgsCommand):
    option_list = base.NoArgsCommand.option_list + (
        make_option('-s', action='store_true', dest='silentmode',
                    default=False, help='Run in silent mode'),
        make_option('--debug', action='store_true',
                    dest='debugmode', default=False,
                    help='Debug mode (overrides silent mode)'),
    )

    @transaction.commit_on_success
    def handle_noargs(self, **options):
        if not options['silentmode']:
            logging.getLogger('djangoproject').setLevel(logging.INFO)
        if options['debugmode']:
            logging.getLogger('djangoproject').setLevel(logging.DEBUG)
        lock = lockfile.FileLock('/tmp/django_spreadsheet_reports_update_weekly_notes')
        lock.acquire(10)
        with lock:
            load_from_urls()
            save_reports(report_type='weekly')
